@@ -6,31 +6,6 @@ path <- tempdir()
 sourcedir <- system.file("inst/testdata", package = "antaresRead")
 if(sourcedir == ""){ sourcedir <- system.file("testdata", package = "antaresRead")}
 
-check_if_h5_is_in_tmp<-function(h5filePath=NULL,path=NULL, stop=FALSE, printMessage=TRUE){
-
-  resH5NotInTmp<-!grepl("Temp", h5filePath, ignore.case = TRUE) & !grepl("tmp", h5filePath, ignore.case = TRUE)
-  if(resH5NotInTmp){
-    if(printMessage){
-      print(paste0("h5file : ", h5filePath))
-      print(paste0("path : ", path))
-    }
-  }else{
-    return(TRUE)
-  }
-
-  messageToPrint<-"h5file is not in temp folder"
-  if(stop & resH5NotInTmp){
-    stop(messageToPrint)
-  }
-  if(resH5NotInTmp){
-    if(printMessage){
-      message(messageToPrint)
-    }
-  }
-
-  return(FALSE)
-}
-
 Sys.unsetenv("R_TESTS")
 # Hack: For some unknown reason, this script is executed at some point of
 # the R CMD CHECK before package is correctly installed and tests actually run.
@@ -57,11 +32,11 @@ if (sourcedir != "") {
       if(file.copy(from = h5file, to = path, overwrite = TRUE)){
         assign("h5file", file.path(path, nameH5File), envir = globalenv())
         #WE MUST assign h5file variable in the test environnement and not in the global environnement
-        if(!check_if_h5_is_in_tmp(h5file, path, printMessage = FALSE)){
+        if(!.check_if_h5_is_in_tmp(h5file, path, printMessage = FALSE)){
           assign("h5file", file.path(path, nameH5File))
         }
 
-        check_if_h5_is_in_tmp(h5file, path)
+        .check_if_h5_is_in_tmp(h5file, path)
       }
     }
 
@@ -75,7 +50,7 @@ if (sourcedir != "") {
       stop("h5file must not be null")
     }
 
-    check_if_h5_is_in_tmp(h5file, path, stop = FALSE)
+    .check_if_h5_is_in_tmp(h5file, path, stop = FALSE)
 
     silentf <- deprintize(showAliases)
     assign("silentf", silentf, envir = globalenv())
